==> activemq-http-5.9.0-atlassian-1-sources.jar: org/apache/activemq/transport/http/HttpTransportSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.transport.http;

import java.net.URI;
import org.apache.activemq.transport.TransportThreadSupport;
import org.apache.activemq.transport.util.TextWireFormat;
import org.apache.activemq.wireformat.WireFormat;

/**
 * A useful base class for HTTP Transport implementations.
 *
 *
 */
public abstract class HttpTransportSupport extends TransportThreadSupport {
    @Deprecated
    private WireFormat textWireFormat;
    private HttpTransportMarshaller marshaller;
    private URI remoteUrl;
    private String proxyHost;
    private int proxyPort = 8080;
    private String proxyUser;
    private String proxyPassword;

    @Deprecated
    public HttpTransportSupport(final TextWireFormat textWireFormat, final URI remoteUrl) {
        this(new HttpTextWireFormatMarshaller(textWireFormat), remoteUrl);
        this.textWireFormat = textWireFormat;
    }

    public HttpTransportSupport(final HttpTransportMarshaller marshaller, final URI remoteUrl) {
        this.marshaller = marshaller;
        this.remoteUrl = remoteUrl;
    }

    public String toString() {
        return "HTTP Reader " + getRemoteUrl();
    }

    // Properties
    // -------------------------------------------------------------------------
    public String getRemoteAddress() {
        return remoteUrl.toString();
    }

    public URI getRemoteUrl() {
        return remoteUrl;
    }

    @Deprecated
    public TextWireFormat getTextWireFormat() {
        return (TextWireFormat) textWireFormat;
    }

    public HttpTransportMarshaller getMarshaller() {
        return marshaller;
    }

    @Deprecated
    public void setTextWireFormat(final TextWireFormat textWireFormat) {
        this.textWireFormat = textWireFormat;
        this.marshaller = new HttpTextWireFormatMarshaller(textWireFormat);
    }

    public String getProxyHost() {
        return proxyHost;
    }

    public void setProxyHost(String proxyHost) {
        this.proxyHost = proxyHost;
    }

    public int getProxyPort() {
        return proxyPort;
    }

    public void setProxyPort(int proxyPort) {
        this.proxyPort = proxyPort;
    }

    public String getProxyUser() {
       return proxyUser;
    }

    public void setProxyUser(String proxyUser) {
       this.proxyUser = proxyUser;
    }

    public String getProxyPassword() {
       return proxyPassword;
    }

    public void setProxyPassword(String proxyPassword) {
       this.proxyPassword = proxyPassword;
    }
}

==> activemq-http-5.13.0-atlassian-1-sources.jar: org/apache/activemq/transport/http/HttpTransportSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.transport.http;

import java.net.URI;

import org.apache.activemq.transport.TransportThreadSupport;
import org.apache.activemq.transport.http.marshallers.HttpTransportMarshaller;
import org.apache.activemq.transport.http.marshallers.TextWireFormatMarshallers;
import org.apache.activemq.transport.util.TextWireFormat;
import org.apache.activemq.wireformat.WireFormat;

/**
 * A useful base class for HTTP Transport implementations.
 *
 *
 */
public abstract class HttpTransportSupport extends TransportThreadSupport {
    @Deprecated
    private WireFormat textWireFormat;
    private HttpTransportMarshaller marshaller;
    private URI remoteUrl;
    private String proxyHost;
    private int proxyPort = 8080;
    private String proxyUser;
    private String proxyPassword;

    @Deprecated
    public HttpTransportSupport(final TextWireFormat textWireFormat, final URI remoteUrl) {
        this(TextWireFormatMarshallers.newTransportMarshaller(textWireFormat), remoteUrl);
        this.textWireFormat = textWireFormat;
    }

    public HttpTransportSupport(final HttpTransportMarshaller marshaller, final URI remoteUrl) {
        this.marshaller = marshaller;
        this.remoteUrl = remoteUrl;
    }

    public String toString() {
        return "HTTP Reader " + getRemoteUrl();
    }

    // Properties
    // -------------------------------------------------------------------------
    public String getRemoteAddress() {
        return remoteUrl.toString();
    }

    public URI getRemoteUrl() {
        return remoteUrl;
    }

    @Deprecated
    public TextWireFormat getTextWireFormat() {
        return (TextWireFormat) textWireFormat;
    }

    public HttpTransportMarshaller getMarshaller() {
        return marshaller;
    }

    @Deprecated
    public void setTextWireFormat(final TextWireFormat textWireFormat) {
        this.textWireFormat = textWireFormat;
        this.marshaller = TextWireFormatMarshallers.newTransportMarshaller(textWireFormat);
    }

    public String getProxyHost() {
        return proxyHost;
    }

    public void setProxyHost(String proxyHost) {
        this.proxyHost = proxyHost;
    }

    public int getProxyPort() {
        return proxyPort;
    }

    public void setProxyPort(int proxyPort) {
        this.proxyPort = proxyPort;
    }

    public String getProxyUser() {
       return proxyUser;
    }

    public void setProxyUser(String proxyUser) {
       this.proxyUser = proxyUser;
    }

    public String getProxyPassword() {
       return proxyPassword;
    }

    public void setProxyPassword(String proxyPassword) {
       this.proxyPassword = proxyPassword;
    }
}
